**************
Reporting bugs
**************

File bug reports or feature requests, and make contributions
(e.g. code patches), by opening a "new issue" on GitHub:

- NumPy Issues: https://github.com/numpy/numpy/issues

Please give as much information as you can in the ticket. It is extremely
useful if you can supply a small self-contained code snippet that reproduces
the problem. Also specify the component, the version you are referring to and
the milestone.

Report bugs to the appropriate GitHub project (there is one for NumPy
and a different one for SciPy).

More information can be found on the
https://www.scipy.org/scipylib/dev-zone.html website.
